@@ -23,7 +23,7 @@
 #' @export
 report.default <- function(x, ...) {
   # You can remove the following line once the functions below are implemented
-  stop(.error_message(x, "report()"))
+  stop(.error_message(x, "report()"), call. = FALSE)
 
   text <- report_text(x, ...)
   table <- report_table(x, ...)
@@ -39,7 +39,7 @@ report_effectsize.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_effectsize()"))
+  stop(.error_message(x, "report_effectsize()"), call. = FALSE)
 
   text <- c("large", "medium", "small")
   text_short <- c("l", "m", "s")
@@ -56,7 +56,7 @@ report_table.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_table()"))
+  stop(.error_message(x, "report_table()"), call. = FALSE)
 
   table <- data.frame(V1 = c(1, 2), V2 = c("A", "B"), V3 = c(42, 7))
   table_short <- table[c("V1", "V2")]
@@ -73,7 +73,7 @@ report_statistics.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_statistics()"))
+  stop(.error_message(x, "report_statistics()"), call. = FALSE)
 
   text <- c("(z = 3, p < .05)", "(z = 1, p > 0.09)")
   text_short <- c("(z = 3)", "(z = 1)")
@@ -90,7 +90,7 @@ report_parameters.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_parameters()"))
+  stop(.error_message(x, "report_parameters()"), call. = FALSE)
 
   text <- c("it's great (z = 3, p < .05)", "it's terrible (z = 1, p > 0.09)")
   text_short <- c("it's great (z = 3)", "it's terrible (z = 1)")
@@ -107,7 +107,7 @@ report_intercept.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_intercept()"))
+  stop(.error_message(x, "report_intercept()"), call. = FALSE)
 
   text <- "The intercept is at 3 (z = 1, p > 0.09)"
   text_short <- "The intercept is at 3 (z = 1)"
@@ -124,7 +124,7 @@ report_model.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_model()"))
+  stop(.error_message(x, "report_model()"), call. = FALSE)
 
   text <- "We fitted a super duper model called the 'easymodel'"
   text_short <- "We fitted a super duper model"
@@ -141,7 +141,7 @@ report_random.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_random()"))
+  stop(.error_message(x, "report_random()"), call. = FALSE)
 
   text <- "The random factors are entered as this and that (formula)"
   text_short <- "The random factors are entered as this and that"
@@ -158,7 +158,7 @@ report_priors.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_priors()"))
+  stop(.error_message(x, "report_priors()"), call. = FALSE)
 
   text <- "Priors were specified like this (formula)"
   text_short <- "Priors were specified like this"
@@ -175,7 +175,7 @@ report_performance.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_performance()"))
+  stop(.error_message(x, "report_performance()"), call. = FALSE)
 
   text <- "The model is simply awesome (p < 0.0001)"
   text_short <- "The model is simply awesome"
@@ -192,7 +192,7 @@ report_info.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_info()"))
+  stop(.error_message(x, "report_info()"), call. = FALSE)
 
   text <- "Degrees of freedom were computed using this method, which does that"
   text_short <- "Degrees of freedom were computed using this method"
@@ -209,7 +209,7 @@ report_text.default <- function(x, ...) {
   # Delete the whole function if it's NOT applicable to your model / object.
   # Don't forget to edit the documentation name above ('rdname report.NEWCLASS')
   # You can remove the following line and fill it with some (working) code :)
-  stop(.error_message(x, "report_text()"))
+  stop(.error_message(x, "report_text()"), call. = FALSE)
 
   text <- paste(
     report_model(x),
